@@ -857,4 +857,38 @@ function delete_parameter
   fi
 
   yetus_del_array_element PARAMETER_TRACKER "${i}"
-}
\ No newline at end of file
+}
+
+## @description  unescape common HTML entities
+## @audience     public
+## @stability    stable
+## @replaceable  no
+## @param        parameter
+function unescape_html
+{
+  declare str=$1
+
+  str="${str//&amp;/&}"
+  str="${str//&quot;/\"}"
+  str="${str//&lt;/<}"
+  str="${str//&gt;/>}"
+  str="${str//&apos;/\'}"
+  echo "${str}"
+}
+
+## @description  escape common HTML entities
+## @audience     public
+## @stability    stable
+## @replaceable  no
+## @param        parameter
+function escape_html
+{
+  declare str=$1
+
+  str="${str//&/&amp;}"
+  str="${str//\"/&quot;}"
+  str="${str//</&lt;}"
+  str="${str//>/&gt;}"
+  str="${str//\'/&apos;}"
+  echo "${str}"
+}
