@@ -31,6 +31,7 @@ DOCKER_SOCKET_GID=-1
 DOCKER_WORK_DIR="/precommit"
 
 declare -a DOCKER_EXTRAARGS
+declare -a DOCKER_EXTRABUILDARGS
 declare -a DOCKER_VERSION
 
 DOCKER_EXTRAENVS+=("JAVA_HOME")
@@ -145,7 +146,7 @@ function docker_parse_args
       ;;
       --docker-work-dir=*)
         delete_parameter "${i}"
-        DOCKER_TAG=${i#*=}
+        DOCKER_WORK_DIR=${i#*=}
       ;;
     esac
   done
@@ -195,8 +196,9 @@ function docker_initialize
 
   dockvers=$(docker_version Client)
   IFS='.' read -r -a DOCKER_VERSION <<< "${dockvers}"
-  if [[ "${DOCKER_VERSION[0]}" -lt 17 ]]; then
-    add_vote_table -1 docker "Docker command '${DOCKERCMD}' is too old (${dockvers} < 17.0)."
+  if [[ "${DOCKER_VERSION[0]}" -lt 1 ]] || \
+     [[ "${DOCKER_VERSION[0]}" -lt 2 && "${DOCKER_VERSION[1]}" -lt 27 ]]; then
+    add_vote_table -1 docker "Docker command '${DOCKERCMD}' is too old (${dockvers} <  API v 1.27.0)."
     bugsystem_finalreport 1
     cleanup_and_exit 1
   fi
@@ -246,7 +248,7 @@ function docker_fileverify
         dockplat=('--platform' "${DOCKER_PLATFORM}")
       fi
 
-      echo "No --dockerfile or --dockertag provided. Attempting to pull apache/yetus:${VERSION}."
+      echo "No --dockerfile or --docker-tag provided. Attempting to pull apache/yetus:${VERSION}."
 
       if dockercmd pull "${dockplat[@]}" "apache/yetus:${VERSION}"; then
         echo "Pull succeeded; will build with pulled image."
@@ -558,7 +560,7 @@ function docker_version
   declare ret
 
   # new version command
-  val=$(dockercmd version --format "{{.${vertype}.Version}}" 2>/dev/null)
+  val=$(dockercmd version --format "{{.${vertype}.APIVersion}}" 2>/dev/null)
   ret=$?
 
   if [[ ${ret} != 0 ]];then
@@ -569,6 +571,23 @@ function docker_version
   echo "${val}"
 }
 
+## @description  Queue Docker build-args to add to the docker build
+## @audience     public
+## @stability    stable
+## @replaceable  yes
+## @param        envname
+## @param        value
+function add_docker_build_arg
+{
+  declare key="$1"
+  declare value="$2"
+  if [[ -z "${value}" ]]; then
+    DOCKER_EXTRABUILDARGS+=("--build-arg" "${key}")
+  else
+    DOCKER_EXTRABUILDARGS+=("--build-arg" "${key}=${value}")
+  fi
+}
+
 ## @description  Queue env vars to add to the docker env
 ## @audience     public
 ## @stability    stable
@@ -658,20 +677,23 @@ function docker_run_image
     lines=$("${AWK}" '/YETUS CUT HERE/ {print FNR; exit}' "${DOCKERFILE}")
 
     buildfile="${PATCH_DIR}/Dockerfile"
-    if [[ "${DOCKER_VERSION[0]}" -lt 18 ]] && [[ ${lines} -gt 0 ]]; then
+    if [[ ${lines} -gt 0 ]]; then
+      if [[ "${DOCKER_VERSION[0]}" -lt 1 ]] || \
+       [[ "${DOCKER_VERSION[0]}" -lt 2 && "${DOCKER_VERSION[1]}" -lt 38 ]]; then
 
-      # versions less than 18 don't support having the
-      # Dockerfile outside of the build context. Let's fall back to
-      # pre-YETUS-723 behavior and put the re-written Dockerfile
-      # outside of the source tree rather than go through a lot of
-      # machinations.  This means COPY, ADD, etc do not work, but
-      # whatever
+        # versions less than 18 don't support having the
+        # Dockerfile outside of the build context. Let's fall back to
+        # pre-YETUS-723 behavior and put the re-written Dockerfile
+        # outside of the source tree rather than go through a lot of
+        # machinations.  This means COPY, ADD, etc do not work, but
+        # whatever
 
-      popd >/dev/null || return 1
-      buildfile="${PATCH_DIR}/test-patch-docker/Dockerfile"
-      dockerdir="${PATCH_DIR}/test-patch-docker"
-      mkdir -p "${dockerdir}"
-      pushd "${PATCH_DIR}/test-patch-docker" >/dev/null || return 1
+        popd >/dev/null || return 1
+        buildfile="${PATCH_DIR}/test-patch-docker/Dockerfile"
+        dockerdir="${PATCH_DIR}/test-patch-docker"
+        mkdir -p "${dockerdir}"
+        pushd "${PATCH_DIR}/test-patch-docker" >/dev/null || return 1
+      fi
     fi
 
     (
@@ -682,10 +704,13 @@ function docker_run_image
       fi
     ) > "${buildfile}"
 
-    if [[ "${DOCKER_VERSION[0]}" -lt 18 ]] && [[ ${lines} -gt 0 ]]; then
-      # Need to put our re-constructed Dockerfile in a place
-      # where it can be referenced in the output post-run
-      cp -p "${buildfile}" "${PATCH_DIR}/Dockerfile"
+    if [[ ${lines} -gt 0 ]]; then
+      if [[ "${DOCKER_VERSION[0]}" -lt 1 ]] || \
+       [[ "${DOCKER_VERSION[0]}" -lt 2 && "${DOCKER_VERSION[1]}" -lt 38 ]]; then
+        # Need to put our re-constructed Dockerfile in a place
+        # where it can be referenced in the output post-run
+        cp -p "${buildfile}" "${PATCH_DIR}/Dockerfile"
+      fi
     fi
 
     if [[ -n "${DOCKER_CACHE_FROM}" ]]; then
@@ -702,6 +727,7 @@ function docker_run_image
           --label org.apache.yetus=\"\" \
           --label org.apache.yetus.testpatch.project="${PROJECT_NAME}" \
           --tag "${baseimagename}" \
+          "${DOCKER_EXTRABUILDARGS[@]}" \
           -f "${buildfile}" \
           "${dockerdir}"; then
       popd >/dev/null || return 1
@@ -744,6 +770,7 @@ function docker_run_image
     --build-arg USER_NAME="${USER_NAME}" \
     --build-arg DOCKER_SOCKET_GID="${DOCKER_SOCKET_GID}" \
     --build-arg DOCKER_WORK_DIR="${DOCKER_WORK_DIR}" \
+    "${DOCKER_EXTRABUILDARGS[@]}" \
     --label org.apache.yetus=\"\" \
     --label org.apache.yetus.testpatch.patch="tp-${DOCKER_ID}" \
     --label org.apache.yetus.testpatch.project="${PROJECT_NAME}" \
@@ -779,7 +806,7 @@ function docker_run_image
   client=$(docker_version Client)
   server=$(docker_version Server)
 
-  dockerversion="Client=${client} Server=${server}"
+  dockerversion="ClientAPI=${client} ServerAPI=${server}"
 
   # make the kernel prefer to kill us if we run out of RAM
   DOCKER_EXTRAARGS+=("--oom-score-adj" "500")
