@@ -33,8 +33,9 @@ GITHUB_API_URL="https://api.github.com"
 GITHUB_REPO=""
 
 # user settings
-GITHUB_PASSWD=""
-GITHUB_USER=""
+GITHUB_PASSWD="${GITHUB_PASSWD-}"
+GITHUB_USER="${GITHUB_USER-}"
+GITHUB_TOKEN="${GITHUB_TOKEN-}"
 GITHUB_ISSUE=""
 GITHUB_USE_EMOJI_VOTE=false
 
@@ -56,8 +57,10 @@ function github_usage
 
   yetus_add_option "--github-api-url=<url>" "The URL of the API for github (default: '${GITHUB_API_URL}')"
   yetus_add_option "--github-base-url=<url>" "The URL of the github server (default:'${GITHUB_BASE_URL}')"
-  yetus_add_option "--github-password=<pw>" "Github password (or OAuth token)"
+# Do not extract GITHUB_PASSWD environment variable
+  yetus_add_option "--github-password=<pw>" "Github password (or OAuth token) (default: 'GITHUB_PASSWD' environment variable)"
   yetus_add_option "--github-repo=<repo>" "github repo to use (default:'${GITHUB_REPO}')"
+  yetus_add_option "--github-token=<token>" "The token to use to read/write to github"
   yetus_add_option "--github-user=<user>" "Github user [default: ${GITHUB_USER}]"
   yetus_add_option "--github-use-emoji-vote" "Whether to use emoji to represent the vote result on github [default: ${GITHUB_USE_EMOJI_VOTE}]"
 }
@@ -86,6 +89,10 @@ function github_parse_args
         delete_parameter "${i}"
         GITHUB_PASSWD=${i#*=}
       ;;
+      --github-token=*)
+        delete_parameter "${i}"
+        GITHUB_TOKEN=${i#*=}
+      ;;
       --github-user=*)
         delete_parameter "${i}"
         GITHUB_USER=${i#*=}
@@ -313,7 +320,9 @@ function github_locate_pr_patch
   # shellcheck disable=SC2034
   PATCHURL="${GITHUB_BASE_URL}/${GITHUB_REPO}/pull/${input}.patch"
 
-  if [[ -n "${GITHUB_USER}"
+  if [[ -n "${GITHUB_TOKEN}" ]]; then
+    githubauth=(-H "Authorization: token ${GITHUB_TOKEN}")
+  elif [[ -n "${GITHUB_USER}"
      && -n "${GITHUB_PASSWD}" ]]; then
     githubauth=(-u "${GITHUB_USER}:${GITHUB_PASSWD}")
   else
@@ -392,7 +401,9 @@ function github_locate_sha_patch
   # locate the PR number via GitHub API v3
   #curl https://api.github.com/search/issues?q=sha:40a7af3377d8087779bf8ad66397947b7270737a\&type:pr\&repo:apache/yetus
 
-  if [[ -n "${GITHUB_USER}"
+  if [[ -n "${GITHUB_TOKEN}" ]]; then
+    githubauth=(-H "Authorization: token ${GITHUB_TOKEN}")
+  elif [[ -n "${GITHUB_USER}"
      && -n "${GITHUB_PASSWD}" ]]; then
     githubauth=(-u "${GITHUB_USER}:${GITHUB_PASSWD}")
   else
@@ -413,22 +424,33 @@ function github_locate_sha_patch
   number=$("${GREP}" number "${PATCH_DIR}/github-search.json" | \
            head -1 | \
            "${AWK}" '{print $NF}')
-  number=${number//\s/}
+  number=${number//\s}
   number=${number%,}
 
   # Semaphore CI doesn't tell us if the sha is a PR or not, so...
-  if [[ -z "${number}" ]] && [[ "${ROBOTTYPE}" = semaphoreci ]]; then
+  if [[ -z "${number}" ]]; then
+     if [[ "${ROBOTTYPE}" = semaphoreci ]]; then
 
-    echo "This appears to be a full build on Semaphore CI. Switching modes."
+      echo "This appears to be a full build on Semaphore CI. Switching modes."
 
-    PATCH_BRANCH=${SEMAPHORE_GIT_BRANCH}
+      PATCH_BRANCH=${SEMAPHORE_GIT_BRANCH}
 
-    # shellcheck disable=SC2034
-    PATCH_OR_ISSUE=""
-    # shellcheck disable=SC2034
-    BUILDMODE=full
-    set_buildmode
-    return 0
+      # shellcheck disable=SC2034
+      PATCH_OR_ISSUE=""
+      # shellcheck disable=SC2034
+      BUILDMODE=full
+      add_docker_env BUILDMODE
+      set_buildmode
+      return 0
+    else
+      # shellcheck disable=SC2034
+      PATCH_OR_ISSUE=""
+      # shellcheck disable=SC2034
+      BUILDMODE=full
+      add_docker_env BUILDMODE
+      set_buildmode
+      return 0
+    fi
   fi
 
   github_locate_pr_patch "GH:${number}" "${patchout}" "${diffout}"
@@ -503,7 +525,9 @@ function github_linecomments
     echo "}"
   } > "${tempfile}"
 
-  if [[ -n "${GITHUB_USER}"
+  if [[ -n "${GITHUB_TOKEN}" ]]; then
+    githubauth=(-H "Authorization: token ${GITHUB_TOKEN}")
+  elif [[ -n "${GITHUB_USER}"
      && -n "${GITHUB_PASSWD}" ]]; then
     githubauth=(-u "${GITHUB_USER}:${GITHUB_PASSWD}")
   else
@@ -546,7 +570,9 @@ function github_write_comment
     echo "\"}"
   } > "${restfile}"
 
-  if [[ -n "${GITHUB_USER}"
+  if [[ -n "${GITHUB_TOKEN}" ]]; then
+    githubauth=(-H "Authorization: token ${GITHUB_TOKEN}")
+  elif [[ -n "${GITHUB_USER}"
      && -n "${GITHUB_PASSWD}" ]]; then
     githubauth=(-u "${GITHUB_USER}:${GITHUB_PASSWD}")
   else
